.. pybids-reports documentation master file, created by
   sphinx-quickstart on Sun Jan 22 22:02:22 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pybids-reports's documentation!
==========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   reports
   cli
   examples


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
